@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::RenderSteps;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub register {
   my ($self, $app) = @_;
@@ -12,7 +12,7 @@ sub register {
       $self->render_later;
       $self->stash->{'rendersteps.depth'}++;
       my $delay = Mojo::IOLoop->delay(@steps);
-      $delay->on(error => sub { $self->render_exception(shift) });
+      $delay->on(error => sub { $self->render_exception(pop) });
       $delay->on(
         finish => sub {
           my $delay = shift;
